# Furo MyST-NB CSS Fixes
> A tiny wrapper around a few lines of CSS to better support the MyST-NB Jupyter notebook outputs with the Furo Sphinx theme.

<!-- [![Tests](https://img.shields.io/github/workflow/status/kai-tub/furo-myst-nb-css-fixes/CI?color=dark-green&label=%20Tests)](https://github.com/kai-tub/furo-myst-nb-css-fixes//actions/workflows/main.yml) -->
[![License](https://img.shields.io/pypi/l/furo-myst-nb-css-fixes?color=dark-green)](https://github.com/kai-tub/furo-myst-nb-css-fixes//blob/main/LICENSE)
[![PyPI version](https://img.shields.io/pypi/v/furo-myst-nb-css-fixes)](https://pypi.org/project/furo-myst-nb-css-fixes)
[![Python Versions](https://img.shields.io/pypi/pyversions/furo-myst-nb-css-fixes)](https://pypi.org/project/furo-myst-nb-css-fixes)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm.fming.dev)
[![Auto Release](https://img.shields.io/badge/release-auto.svg?colorA=888888&colorB=blueviolet&label=auto&logo=data:image/png;base64, )](https://github.com/intuit/auto)
<!-- [![Conda Version](https://img.shields.io/conda/vn/conda-forge/furo-myst-nb-css-fixes?color=dark-green)](https://anaconda.org/conda-forge/furo-myst-nb-css-fixes) -->

:::{important}

Very much a work in progress!
May currently break more things than it helps!

:::
